@@ -30,17 +30,18 @@
 #include "calendarview.h"
 #include "koglobals.h"
 
-#include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
 #include <EventViews/ListView>
+#include <PimCommon/PimUtil>
 
 #include <KMessageBox>
-#include <PimCommon/PimUtil>
 #include <KConfigGroup>
+#include <KGuiItem>
+#include <KSharedConfig>
+
 #include <QDialogButtonBox>
 #include <QPushButton>
-#include <KGuiItem>
 #include <QVBoxLayout>
 
 using namespace KOrg;
@@ -161,31 +162,29 @@ void SearchDialog::search(const QRegExp &re)
     const QDate endDt = m_ui->endDate->date();
 
     KCalCore::Event::List events;
-    KDateTime::Spec timeSpec = CalendarSupport::KCalPrefs::instance()->timeSpec();
     if (m_ui->eventsCheck->isChecked()) {
         events =
             m_calendarview->calendar()->events(
-                startDt, endDt, timeSpec, m_ui->inclusiveCheck->isChecked());
+                startDt, endDt, QTimeZone::systemTimeZone(), m_ui->inclusiveCheck->isChecked());
     }
 
     KCalCore::Todo::List todos;
 
     if (m_ui->todosCheck->isChecked()) {
         if (m_ui->includeUndatedTodos->isChecked()) {
-            KDateTime::Spec spec = CalendarSupport::KCalPrefs::instance()->timeSpec();
             const KCalCore::Todo::List alltodos = m_calendarview->calendar()->todos();
             for (const KCalCore::Todo::Ptr &todo : alltodos) {
                 Q_ASSERT(todo);
                 if ((!todo->hasStartDate() && !todo->hasDueDate()) ||    // undated
                         (todo->hasStartDate() &&
-                         (todo->dtStart().toTimeSpec(spec).date() >= startDt) &&
-                         (todo->dtStart().toTimeSpec(spec).date() <= endDt)) ||      //start dt in range
+                         (todo->dtStart().toLocalTime().date() >= startDt) &&
+                         (todo->dtStart().toLocalTime().date() <= endDt)) ||      //start dt in range
                         (todo->hasDueDate() &&
-                         (todo->dtDue().toTimeSpec(spec).date() >= startDt) &&
-                         (todo->dtDue().toTimeSpec(spec).date() <= endDt)) ||      //due dt in range
+                         (todo->dtDue().toLocalTime().date() >= startDt) &&
+                         (todo->dtDue().toLocalTime().date() <= endDt)) ||      //due dt in range
                         (todo->hasCompletedDate() &&
-                         (todo->completed().toTimeSpec(spec).date() >= startDt) &&
-                         (todo->completed().toTimeSpec(spec).date() <= endDt))) {      //completed dt in range
+                         (todo->completed().toLocalTime().date() >= startDt) &&
+                         (todo->completed().toLocalTime().date() <= endDt))) {      //completed dt in range
                     todos.append(todo);
                 }
             }
