@@ -35,7 +35,6 @@
 #include <KIO/MkdirJob>
 #include <KJobWidgets>
 #include <KLocalizedString>
-#include <QDialog>
 
 #include <QGroupBox>
 #include <QHBoxLayout>
@@ -46,7 +45,6 @@
 #include <QUiLoader>
 #include <QWhatsThis>
 #include <QDir>
-#include <KConfigGroup>
 
 class PageItem : public QTreeWidgetItem
 {
@@ -201,7 +199,7 @@ void KCMDesignerFields::deleteFile()
 void KCMDesignerFields::importFile()
 {
     QUrl src = QFileDialog::getOpenFileUrl(this, i18n("Import Page"), QUrl::fromLocalFile(QDir::homePath()),
-                                           i18n("Designer Files (*.ui)")
+                                           QStringLiteral("%1 (*.ui)").arg(i18n("Designer Files"))
                                           );
     QUrl dest = QUrl::fromLocalFile(localUiDir());
     QDir().mkpath(localUiDir());
